<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
  <context>
    <name>CmdApproxCylinder</name>
    <message>
      <location filename="../../Command.cpp" line="248"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="249"/>
      <source>Cylinder</source>
      <translation>Ritinys</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="250"/>
      <source>Approximate a cylinder</source>
      <translation>Apytikslis ritinys</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="140"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="141"/>
      <source>Plane</source>
      <translation>Plokštuma</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="142"/>
      <source>Approximate a plane</source>
      <translation>Apytikslė plokštuma</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPolynomial</name>
    <message>
      <location filename="../../Command.cpp" line="364"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="365"/>
      <source>Polynomial surface</source>
      <translation>Polinominis paviršius</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="366"/>
      <source>Approximate a polynomial surface</source>
      <translation>Gauti apytikslį polinominį paviršių</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSphere</name>
    <message>
      <location filename="../../Command.cpp" line="316"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="317"/>
      <source>Sphere</source>
      <translation>Rutulys</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="318"/>
      <source>Approximate a sphere</source>
      <translation>Apytikslis rutulys</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Approximate B-spline surface...</source>
      <translation>Apytikslis B-splaininis paviršius...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Approximate a B-spline surface</source>
      <translation>Apytikslis B-splaininis paviršius</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshBoundary</name>
    <message>
      <location filename="../../Command.cpp" line="536"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="537"/>
      <source>Wire from mesh boundary...</source>
      <translation>Rėmas iš tinklo ribų...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="538"/>
      <source>Create wire from mesh boundaries</source>
      <translation>Sukurti rėmą iš tinklo ribų</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location filename="../../Command.cpp" line="603"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="604"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="605"/>
      <source>Poisson surface reconstruction</source>
      <translation>Puasono paviršiaus atkūrimas</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentation</name>
    <message>
      <location filename="../../Command.cpp" line="422"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="423"/>
      <source>Mesh segmentation...</source>
      <translation>Tinklo skaidymas...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="424"/>
      <source>Create mesh segments</source>
      <translation>Sukuria tinklo atkarpas</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationFromComponents</name>
    <message>
      <location filename="../../Command.cpp" line="484"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="485"/>
      <source>From components</source>
      <translation>Iš dalių</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="486"/>
      <source>Create mesh segments from components</source>
      <translation>Sukurti tinklo dalis iš sudėtinių dalių</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationManual</name>
    <message>
      <location filename="../../Command.cpp" line="454"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="455"/>
      <source>Manual segmentation...</source>
      <translation>Rankinis skaidymas...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="456"/>
      <source>Create mesh segments manually</source>
      <translation>Sukurti tinklo skaidinius rankiniu būdu</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="638"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="639"/>
      <source>Structured point clouds</source>
      <translation>Sudėtiniai aibės taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="640"/>
      <location filename="../../Command.cpp" line="641"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Sudėtinių taškų aibių trianguliacija</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="226"/>
      <source>Fit plane</source>
      <translation>Priderinti plokštumą</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="258"/>
      <source>Fit cylinder</source>
      <translation>Priderinti ritinį</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="326"/>
      <source>Fit sphere</source>
      <translation>Priderinti rutulį</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>Fit polynomial surface</source>
      <translation>Priderinti polinominį paviršių</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="650"/>
      <source>View triangulation</source>
      <translation>Rodyti trianguliaciją</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="154"/>
      <source>Placement</source>
      <translation>Padėtis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="231"/>
      <location filename="../../FitBSplineCurve.cpp" line="139"/>
      <source>Fit B-spline</source>
      <translation>Pritaikyti B-splainą</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="83"/>
      <source>Poisson reconstruction</source>
      <translation>Puasono atkūrimas</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.cpp" line="281"/>
      <source>Segmentation</source>
      <translation>Segmentacija</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="14"/>
      <source>Fit B-spline surface</source>
      <translation>Priderinti B-splaininį paviršių</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="20"/>
      <source>u-Direction</source>
      <translation>u kryptis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="26"/>
      <location filename="../../FitBSplineSurface.ui" line="93"/>
      <source>Degree</source>
      <translation>Eilė</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="55"/>
      <location filename="../../FitBSplineSurface.ui" line="122"/>
      <source>Control points</source>
      <translation>Valdantieji taškai</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="87"/>
      <source>v-Direction</source>
      <translation>v kryptis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="154"/>
      <source>Settings</source>
      <translation>Nuostatos</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="160"/>
      <source>Iterations</source>
      <translation>Žingsniai</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="189"/>
      <source>Size factor</source>
      <translation>Dydžio koeficientas</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="218"/>
      <source>User-defined u/v directions</source>
      <translation>Vartotojo apibrėžtos u/v kryptys</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="231"/>
      <source>Create placement</source>
      <translation>Kurti išdėstymą</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="238"/>
      <source>Smoothing</source>
      <translation>Glodinimas</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="247"/>
      <source>Total Weight</source>
      <translation>Bendras svoris</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="276"/>
      <source>Length of gradient</source>
      <translation>Perėjimo ilgis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="305"/>
      <source>Bending energy</source>
      <translation>Lenkimo energija</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="334"/>
      <source>Curvature variation</source>
      <translation>Kreivio kitimas</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="165"/>
      <location filename="../../FitBSplineSurface.cpp" line="238"/>
      <source>Input error</source>
      <translation>Įvesties klaida</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="206"/>
      <source>Wrong selection</source>
      <translation>Netinkama pasirinktis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="207"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Prašome pasirinkti vieną dėstymo objektą gauti vietos orientacijai.</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="20"/>
      <source>Parameters</source>
      <translation>Dydžiai</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="26"/>
      <source>Octree depth</source>
      <translation>Aštuntainio medžio gylis</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="46"/>
      <source>Solver divide</source>
      <translation>Sprendiklio dalinimas</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="66"/>
      <source>Samples per node</source>
      <translation>Atskaitų kiekis mazgui</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="90"/>
      <source>Input error</source>
      <translation>Įvesties klaida</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="82"/>
      <location filename="../../Command.cpp" line="120"/>
      <location filename="../../Command.cpp" line="618"/>
      <source>Wrong selection</source>
      <translation>Netinkama pasirinktis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Please select a point cloud.</source>
      <translation>Pasirinkti taškų aibę.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="121"/>
      <source>Please select a point cloud or mesh.</source>
      <translation>Pasirinkite taškų debesį arba tinklą.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="619"/>
      <source>Please select a single point cloud.</source>
      <translation>Prašome pasirinkti vieną taškų aibę.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="672"/>
      <source>View triangulation failed</source>
      <translation>Trianguliacijos rodymas sutriko</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::Segmentation</name>
    <message>
      <location filename="../../Segmentation.ui" line="14"/>
      <source>Mesh segmentation</source>
      <translation>Tinklo skaidymas</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="20"/>
      <source>Smooth mesh</source>
      <translation>Glodinti tinklą</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="37"/>
      <source>Plane</source>
      <translation>Plokštuma</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="46"/>
      <source>Curvature tolerance</source>
      <translation>Kreivio leidžiamoji nuokrypa</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="63"/>
      <source>Distance to plane</source>
      <translation>Atstumas iki plokštumos</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="80"/>
      <source>Minimum number of faces</source>
      <translation>Mažiausias daugiakampių kiekis</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="100"/>
      <source>Create mesh from unused triangles</source>
      <translation>Sukurti tinklą iš nepanaudotų trikampių</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="107"/>
      <source>Create compound</source>
      <translation>Kurti junginius</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::SegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.ui" line="14"/>
      <source>Manual segmentation</source>
      <translation>Rankinis skaidymas</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="20"/>
      <source>Select</source>
      <translation>Pasirinkti</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="41"/>
      <source>Region</source>
      <translation>Sritis</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="61"/>
      <source>All</source>
      <translation>Visi</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="81"/>
      <source>Components</source>
      <translation>Dalys</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="88"/>
      <source>&lt; faces than</source>
      <translation>&lt; daugiakampių, nei</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="98"/>
      <source>Pick triangle</source>
      <translation>Pasirinkti trukampį</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="105"/>
      <source>Select whole component</source>
      <translation>Pažymėti visą dalį</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="112"/>
      <source>Clear</source>
      <translation>Išvalyti</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="122"/>
      <source>Plane</source>
      <translation>Plokštuma</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="128"/>
      <location filename="../../SegmentationManual.ui" line="181"/>
      <location filename="../../SegmentationManual.ui" line="234"/>
      <source>Detect</source>
      <translation>Aptikti</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="135"/>
      <location filename="../../SegmentationManual.ui" line="188"/>
      <location filename="../../SegmentationManual.ui" line="241"/>
      <source>Tolerance</source>
      <translation>Leidžiamoji nuokrypa</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="155"/>
      <location filename="../../SegmentationManual.ui" line="208"/>
      <location filename="../../SegmentationManual.ui" line="261"/>
      <source>Minimum number of faces</source>
      <translation>Mažiausias daugiakampių kiekis</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="175"/>
      <source>Cylinder</source>
      <translation>Ritinys</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="228"/>
      <source>Sphere</source>
      <translation>Rutulys</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="281"/>
      <source>Region options</source>
      <translation>Srities parinktys</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="287"/>
      <source>Respect only visible triangles</source>
      <translation>Priimti tik matomus trikampius</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="297"/>
      <source>Respect only triangles with normals facing screen</source>
      <translation>Priimti tik trikampius, kurių normalės nukreiptos į išorę</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="310"/>
      <source>Segmentation</source>
      <translation>Segmentacija</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="316"/>
      <source>Cut segment from mesh</source>
      <translation>Iškirpti tinklo dalį</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="326"/>
      <source>Hide segment</source>
      <translation>Slėpti atkarpą</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::TaskSegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.cpp" line="352"/>
      <source>Create</source>
      <translation>Sukurti</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineCurve</name>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="14"/>
      <source>Fit B-spline surface</source>
      <translation>Priderinti B-splaininį paviršių</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="20"/>
      <source>Parameters</source>
      <translation>Dydžiai</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="26"/>
      <source>Maximum degree</source>
      <translation>Didžiausias kreivės laipsnis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="37"/>
      <source>Chord length</source>
      <translation>Stygos ilgis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="42"/>
      <source>Centripetal</source>
      <translation>Įcentrinis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="47"/>
      <source>Iso-Parametric</source>
      <translation>Vienodų parametrų</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="55"/>
      <source>Continuity</source>
      <translation>Glotnumas</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="88"/>
      <source>Parametrization type</source>
      <translation>Parametrizacijos rūšis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="96"/>
      <source>C0</source>
      <translation>C0</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="101"/>
      <source>G1</source>
      <translation>G1</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="106"/>
      <source>C1</source>
      <translation>C1</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="111"/>
      <source>G2</source>
      <translation>G2</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="116"/>
      <source>C2</source>
      <translation>C2</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="121"/>
      <source>C3</source>
      <translation>C3</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="126"/>
      <source>CN</source>
      <translation>CN</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="134"/>
      <source>Minimum degree</source>
      <translation>Mažiausias kreivės laipsnis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="141"/>
      <source>Closed curve</source>
      <translation>Uždaroji kreivė</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="151"/>
      <source>Smoothing</source>
      <translation>Glodinimas</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="160"/>
      <source>Torsion</source>
      <translation>Sukimas</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="167"/>
      <source>Curve length</source>
      <translation>Kreivės ilgis</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="174"/>
      <source>Curvature</source>
      <translation>Kreivis</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxCurve</name>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="70"/>
      <source>Approximate B-spline curve...</source>
      <translation>Gauti apytikslę B-splaininę kreivę...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="71"/>
      <source>Approximate a B-spline curve</source>
      <translation>Gauti apytikslę B-splaininę kreivę</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineCurveWidget</name>
    <message>
      <location filename="../../FitBSplineCurve.cpp" line="91"/>
      <source>Input error</source>
      <translation>Įvesties klaida</translation>
    </message>
  </context>
</TS>
